*****************************************************************************************
/* 	Analysis
	Conjoint Spanish survey
	June 2015
*/
*****************************************************************************************

cd "~/Dropbox/papers in progress/conjoint/data/"
use "co_data.dta"

*****************************************************************************************

****Main results
reg vote i.changes i.recipient i.training i.cost b4.source, vce(cluster numericalId)
outreg2 using "Fig1.xls", ctitle(All) excel bdec(3) stats(coef se) replace

reg vote i.changes i.recipient i.training i.cost i.source, vce(cluster numericalId)
estimates store main

coefplot main , drop(_cons) xline(0, lcolor(gs10)) base  ///
			headings(	1.changes = "{bf:Generosity}" ///
						1.recipient = "{bf:Coverage}" ///
						1.training = "{bf:Training}" ///
						1.cost = "{bf:Costs}" ///
						1.source = "{bf:Funding}" ///
						, gap(0.4) labcolor(cranberry) labsize(small)) ///
			msize(vsmall) norecycle ///
			plotregion(margin(vsmall)) plotregion(margin(none)) ///
			ysize(10) xsize(10)   ///
			ylabel(, labsize(small)) xlabel(, labsize(small)) 
			
*****************************************************************************************			
***Individual differences
			
*Material interests
*Employment situation: Temporary
reg vote i.changes##i.emplsit i.training##i.emplsit i.recipient##i.emplsit ///
	i.cost##i.emplsit i.source##i.emplsit if emplsit==1 | emplsit==2, vce(cluster numericalId)
outreg2 using "Tab2.xls", ctitle(Perm-Temp) excel bdec(3) stats(coef se) replace

*Employment situation: Unemployed
reg vote i.changes##i.emplsit i.training##i.emplsit i.recipient##i.emplsit ///
	i.cost##i.emplsit i.source##i.emplsit if emplsit==1 | emplsit==4, vce(cluster numericalId)
outreg2 using "Tab2.xls", ctitle(Perm-Unempl) excel bdec(3) stats(coef se) append

*Occupational risk
reg vote i.changes##c.occrisk i.training##c.occrisk i.recipient##c.occrisk ///
	i.cost##c.occrisk i.source##c.occrisk, vce(cluster numericalId)
outreg2 using "Tab2.xls", ctitle(Occrisk) excel bdec(3) stats(coef se) append

*Chance of losing job	
reg vote i.changes##c.loosejob i.training##c.loosejob i.recipient##c.loosejob ///
	i.cost##c.loosejob i.source##c.loosejob, vce(cluster numericalId)
outreg2 using "Tab2.xls", ctitle(Loosejob) excel bdec(3) stats(coef se) append

*Buffer
reg vote i.changes##c.Q53 i.training##c.Q53 i.recipient##c.Q53 ///
	i.cost##c.Q53 i.source##c.Q53, vce(cluster numericalId)
outreg2 using "Tab2.xls", ctitle(Buffers) excel bdec(3) stats(coef se) append

*Income
reg vote i.changes##c.Q44 i.training##c.Q44 i.recipient##c.Q44 ///
	i.cost##c.Q44 i.source##c.Q44, vce(cluster numericalId)
outreg2 using "Tab2.xls", ctitle(Income) excel bdec(3) stats(coef se) append

*Education
reg vote i.changes##c.int_nivelestudios i.training##c.int_nivelestudios i.recipient##c.int_nivelestudios ///
	i.cost##c.int_nivelestudios i.source##c.int_nivelestudios, vce(cluster numericalId)
outreg2 using "Tab2.xls", ctitle(Education) excel bdec(3) stats(coef se) append			


***Ideology
reg vote i.changes##c.ideol i.training##c.ideol i.recipient##c.ideol i.cost##c.ideol ///
	i.source##c.ideol, vce(cluster numericalId)
outreg2 using "Tab1.xls", ctitle(Ideology) excel bdec(3) stats(coef se) replace
			
 **Interaction effects, Figure 2
 reg vote i.changes##c.ideol i.training##c.ideol i.recipient##c.ideol i.cost##c.ideol ///
	i.source##c.ideol, vce(cluster numericalId)
 margins cost, at(ideol=(0(1)10))
 marginsplot
 
 recode cost (1=0) (2=.) (3=.) (4=1), gen(costminmax)
 reg vote i.changes##c.ideol i.training##c.ideol i.recipient##c.ideol i.costminmax##c.ideol ///
	i.source##c.ideol, vce(cluster numericalId)

**Figure 2
 margins, dydx(costminmax) at(ideol=(0(1)10)) 
 marginsplot, yline(0)
 
 
********************************************************************************
 
*SI: Graphical approach	(Appendix)

*By employment situation and household income
			
reg vote i.changes i.recipient i.training i.cost i.source if emplsit==1, vce(cluster numericalId)
estimates store empl
reg vote i.changes i.recipient i.training i.cost i.source if emplsit==2, vce(cluster numericalId)
estimates store temp
reg vote i.changes i.recipient i.training i.cost i.source if emplsit==4, vce(cluster numericalId)
estimates store unempl
reg vote i.changes i.recipient i.training i.cost i.source if inc3c==1, vce(cluster numericalId)
estimates store inc1
reg vote i.changes i.recipient i.training i.cost i.source if inc3c==2, vce(cluster numericalId)
estimates store inc2
reg vote i.changes i.recipient i.training i.cost i.source if inc3c==3, vce(cluster numericalId)
estimates store inc3

coefplot 	(empl, label(Permanent) offset(0.2) ) ///
			(temp, label(Temporary) msymbol(T) ) /// 
			(unempl, label(Unemployed) offset(-0.2) ), bylabel(Employment situat.) || /// 
			(inc1, label(Up to 1,160) offset(0.2) msymbol(Oh)) ///
			(inc2, label(1,161-1,750) msymbol(Th)) /// 
			(inc3, label(More than 1,750) offset(-0.2) msymbol(Sh)), bylabel(Household income) || ///
			, drop(_cons) xline(0, lcolor(gs10)) base  ///
			headings(	1.changes = "{bf:Generosity}" ///
						1.recipient = "{bf:Coverage}" ///
						1.training = "{bf:Training}" ///
						1.cost = "{bf:Costs}" ///
						1.source = "{bf:Funding}" ///
						, gap(0.4) labcolor(cranberry) labsize(small)) ///
			msize(vsmall) norecycle ///
			legend(rows(3) colfirst region(lwidth(none)) size(small) rowgap(minuscule) bmargin(minuscule) ) ///
			plotregion(margin(vsmall)) plotregion(margin(none)) ///
			ysize(10) xsize(10)   ///
			ylabel(, labsize(small)) xlabel(, labsize(small)) 

*By risk: riskjob occrisk3c		
reg vote i.changes i.recipient i.training i.cost i.source if riskjob==1, vce(cluster numericalId)
estimates store risksub1
reg vote i.changes i.recipient i.training i.cost i.source if riskjob==2, vce(cluster numericalId)
estimates store risksub2
reg vote i.changes i.recipient i.training i.cost i.source if riskjob==3, vce(cluster numericalId)
estimates store risksub3
reg vote i.changes i.recipient i.training i.cost i.source if occrisk3c==0, vce(cluster numericalId)
estimates store riskobj1
reg vote i.changes i.recipient i.training i.cost i.source if occrisk3c==1, vce(cluster numericalId)
estimates store riskobj2
reg vote i.changes i.recipient i.training i.cost i.source if occrisk3c==2, vce(cluster numericalId)
estimates store riskobj3

coefplot 	(risksub1, label(Low subjective) offset(0.2) ) ///
			(risksub2, label(Medium subjective) msymbol(T) ) /// 
			(risksub3, label(High subjective) offset(-0.2) ), bylabel(Subjective risk) || /// 
			(riskobj1, label(Low occupational) offset(0.2) msymbol(Oh)) ///
			(riskobj2, label(Medium occupational) msymbol(Th)) /// 
			(riskobj3, label(High occupational) offset(-0.2) msymbol(Sh)), bylabel(Objective risk) || ///
			, drop(_cons) xline(0, lcolor(gs10)) base  ///
			headings(	1.changes = "{bf:Generosity}" ///
						1.recipient = "{bf:Coverage}" ///
						1.training = "{bf:Training}" ///
						1.cost = "{bf:Costs}" ///
						1.source = "{bf:Funding}" ///
						, gap(0.4) labcolor(cranberry) labsize(small)) ///
			msize(vsmall) norecycle ///
			legend(rows(3) colfirst region(lwidth(none)) size(small) rowgap(minuscule) bmargin(minuscule) ) ///
			plotregion(margin(vsmall)) plotregion(margin(none)) ///
			ysize(10) xsize(10)   ///
			ylabel(, labsize(small)) xlabel(, labsize(small)) 

			
***Ideology

**Appendix
reg vote i.changes i.recipient i.training i.cost i.source if ide3c==1, vce(cluster numericalId)
estimates store ide1
reg vote i.changes i.recipient i.training i.cost i.source if ide3c==2, vce(cluster numericalId)
estimates store ide2
reg vote i.changes i.recipient i.training i.cost i.source if ide3c==3, vce(cluster numericalId)
estimates store ide3

coefplot 	(ide1, label(Left-wing) offset(0.2) ) ///
			(ide2, label(Center) msymbol(T) ) /// 
			(ide3, label(Right-wing) offset(-0.2) ), bylabel(Ideology) || /// 
			, drop(_cons) xline(0, lcolor(gs10)) base  ///
			headings(	1.changes = "{bf:Generosity}" ///
						1.recipient = "{bf:Coverage}" ///
						1.training = "{bf:Training}" ///
						1.cost = "{bf:Costs}" ///
						1.source = "{bf:Funding}" ///
						, gap(0.4) labcolor(cranberry) labsize(small)) ///
			msize(vsmall) norecycle ///
			legend(rows(3) colfirst region(lwidth(none)) size(small) rowgap(minuscule) bmargin(minuscule) ) ///
			plotregion(margin(vsmall)) plotregion(margin(none)) ///
			ysize(10) xsize(10)   ///
			ylabel(, labsize(small)) xlabel(, labsize(small)) 

 
********************************Robustness: with controls

***Individual differences
			
*Material interests
*Employment situation: Temporary
reg vote i.changes##i.emplsit i.training##i.emplsit i.recipient##i.emplsit ///
	i.cost##i.emplsit i.source##i.emplsit ///
	EDAD SEXO i.rec_zonanielsen ideol Q40 Q42 i.Q55 ///
	int_nivelestudios occrisk loosejob i.Q53 Q44 if emplsit==1 | emplsit==2 , vce(cluster numericalId)
outreg2 using "Tab2.xls", ctitle(Perm-Temp) excel bdec(3) stats(coef se) replace

*Employment situation: Unemployed
reg vote i.changes##i.emplsit i.training##i.emplsit i.recipient##i.emplsit ///
	i.cost##i.emplsit i.source##i.emplsit  ///
	EDAD SEXO i.rec_zonanielsen ideol Q40 Q42 i.Q55 ///
	int_nivelestudios i.Q53 Q44 if emplsit==1 | emplsit==4, vce(cluster numericalId)
outreg2 using "Tab2.xls", ctitle(Perm-Unempl) excel bdec(3) stats(coef se) append

*Occupational risk
reg vote i.changes##c.occrisk i.training##c.occrisk i.recipient##c.occrisk ///
	i.cost##c.occrisk i.source##c.occrisk ///
	EDAD SEXO i.rec_zonanielsen ideol Q40 Q42 i.Q55 ///
	i.emplsit int_nivelestudios loosejob i.Q53 Q44, vce(cluster numericalId)
outreg2 using "Tab2.xls", ctitle(Occrisk) excel bdec(3) stats(coef se) append

*Chance of losing job	
reg vote i.changes##c.loosejob i.training##c.loosejob i.recipient##c.loosejob ///
	i.cost##c.loosejob i.source##c.loosejob  ///
	EDAD SEXO i.rec_zonanielsen ideol Q40 Q42 i.Q55 ///
	i.emplsit occrisk int_nivelestudios i.Q53 Q44, vce(cluster numericalId)
outreg2 using "Tab2.xls", ctitle(Loosejob) excel bdec(3) stats(coef se) append

*Income
reg vote i.changes##c.Q44 i.training##c.Q44 i.recipient##c.Q44 ///
	i.cost##c.Q44 i.source##c.Q44 ///
	EDAD SEXO i.rec_zonanielsen ideol Q40 Q42 i.Q55 ///
	i.emplsit occrisk loosejob i.Q53 int_nivelestudios, vce(cluster numericalId)
outreg2 using "Tab2.xls", ctitle(Income) excel bdec(3) stats(coef se) append

*Education
reg vote i.changes##c.int_nivelestudios i.training##c.int_nivelestudios i.recipient##c.int_nivelestudios ///
	i.cost##c.int_nivelestudios i.source##c.int_nivelestudios ///
	EDAD SEXO i.rec_zonanielsen ideol Q40 Q42 i.Q55 ///
	i.emplsit occrisk loosejob i.Q53 Q44, vce(cluster numericalId)
outreg2 using "Tab2.xls", ctitle(Education) excel bdec(3) stats(coef se) append		

